[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![codecov](https://codecov.io/gh/mscheltienne/antio/graph/badge.svg?token=ebC07d0dyM)](https://codecov.io/gh/mscheltienne/antio)
[![ci](https://github.com/mscheltienne/antio/actions/workflows/ci.yaml/badge.svg?branch=main)](https://github.com/mscheltienne/antio/actions/workflows/ci.yaml)

# ANT I/O

Python package to handle I/O with the CNT format from ANT Neuro.
This software uses the [LIBEEP Library](http://libeep.sourceforge.net).
